@@ -1,13 +1,8 @@
-/*
-  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
-
-  $Id: dictionary_compiler.cpp,v 1.9 2006/07/09 15:18:41 taku-ku Exp $;
-
-  Copyright (C) 2001-2006 Taku Kudo <taku@chasen.org>
-  Copyright (C) 2004-2006 Nippon Telegraph and Telephone Corporation
-
-*/
-
+//  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+//  $Id: dictionary_compiler.cpp 108 2007-03-05 15:48:45Z taku-ku $;
+//
+//  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
+//  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
 #include <iostream>
 #include <map>
 #include <vector>
@@ -26,46 +21,46 @@
 namespace MeCab {
 
   class DictionaryComplier {
-
   public:
-    static int run(int argc, char **argv)
-    {
-      static const MeCab::Option long_options[] =
-        {
-          { "dicdir",   'd',   ".",   "DIR",    "set DIR as dicdir (default \".\")" },
-          { "outdir",   'o',   ".",   "DIR",    "set DIR as output dir" },
-          { "unknown",  'U',   0,   0,   "build parameters for unknown words" },
-          { "userdic",  'u',   0,   "FILE",   "build user dictionary" },
-          { "charcategory", 'C', 0, 0,   "build character category maps" },
-          { "matrix",    'm',  0,   0,   "build connection matrix" },
-          { "charset",   'c',  MECAB_DEFAULT_CHARSET, "ENC", "dictionary charset (default " MECAB_DEFAULT_CHARSET ")"  },
-          { "charset",   't',  MECAB_DEFAULT_CHARSET, "ENC", "alias of -c"  },
-          { "dcharset",  'f',  MECAB_DEFAULT_CHARSET,
-            "ENC", "assume input dictionary charset as ENC (default " MECAB_DEFAULT_CHARSET ")"  },
-          { "wakati",    'w',  0,   0,   "build wakati-gaki only dictionary", },
-          { "posid",     'p',  0,   0,   "assign Part-of-speech id" },
-          { "version",   'v',  0,   0,   "show the version and exit."  },
-          { "help",      'h',  0,   0,   "show this help and exit."  },
-          { 0, 0, 0, 0 }
-        };
+    static int run(int argc, char **argv) {
+      static const MeCab::Option long_options[] = {
+        { "dicdir",   'd',   ".",   "DIR", "set DIR as dicdir(default \".\")" },
+        { "outdir",   'o',   ".",   "DIR", "set DIR as output dir" },
+        { "unknown",  'U',   0,   0,   "build parameters for unknown words" },
+        { "userdic",  'u',   0,   "FILE",   "build user dictionary" },
+        { "charcategory", 'C', 0, 0,   "build character category maps" },
+        { "matrix",    'm',  0,   0,   "build connection matrix" },
+        { "charset",   'c',  MECAB_DEFAULT_CHARSET, "ENC",
+          "dictionary charset(default " MECAB_DEFAULT_CHARSET ")"  },
+        { "charset",   't',  MECAB_DEFAULT_CHARSET, "ENC", "alias of -c"  },
+        { "dcharset",  'f',  MECAB_DEFAULT_CHARSET,
+          "ENC", "assume input dictionary charset as ENC(default "
+          MECAB_DEFAULT_CHARSET ")"  },
+        { "wakati",    'w',  0,   0,   "build wakati-gaki only dictionary", },
+        { "posid",     'p',  0,   0,   "assign Part-of-speech id" },
+        { "node-format", 'F', 0,  "STR",   "use STR as the user defined node format" },
+        { "version",   'v',  0,   0,   "show the version and exit."  },
+        { "help",      'h',  0,   0,   "show this help and exit."  },
+        { 0, 0, 0, 0 }
+      };
 
       Param param;
 
-      if (! param.open(argc, argv, long_options)) {
+      if (!param.open(argc, argv, long_options)) {
         std::cout << param.what() << "\n\n" <<  COPYRIGHT
                   << "\ntry '--help' for more information." << std::endl;
         return -1;
       }
 
-      if (!param.help_version(long_options)) return 0;
+      if (!param.help_version()) return 0;
 
-      std::string dicdir = param.getProfileString("dicdir");
-      std::string outdir = param.getProfileString("outdir");
-      bool opt_unknown = param.getProfileInt("unknown");
-      bool opt_matrix = param.getProfileInt("matrix");
-      bool opt_charcategory = param.getProfileInt("charcategory");
-      bool opt_sysdic = param.getProfileInt("sysdic");
-      std::string userdic = param.getProfileString("userdic");
+      std::string dicdir = param.get<std::string>("dicdir");
+      std::string outdir = param.get<std::string>("outdir");
+      bool opt_unknown = param.get<bool>("unknown");
+      bool opt_matrix = param.get<bool>("matrix");
+      bool opt_charcategory = param.get<bool>("charcategory");
+      bool opt_sysdic = param.get<bool>("sysdic");
+      std::string userdic = param.get<std::string>("userdic");
 
 #define DCONF(file) create_filename(dicdir, std::string(file)).c_str()
 #define OCONF(file) create_filename(outdir, std::string(file)).c_str()
@@ -75,15 +70,14 @@ namespace MeCab {
 
       std::vector<std::string> dic;
       if (userdic.empty())
-        enum_csv_dictionaries(dicdir.c_str(), dic);
+        enum_csv_dictionaries(dicdir.c_str(), &dic);
       else
         dic = param.rest_args();
 
-      if (! userdic.empty()) {
-
+      if (!userdic.empty()) {
         CHECK_DIE(dic.size()) << "no dictionaries are specified";
 
-        param.setProfile("type", "1");
+        param.set("type", MECAB_USR_DIC);
         Dictionary::compile(param, dic,
                             DCONF(MATRIX_DEF_FILE),
                             DCONF(MATRIX_FILE),
@@ -92,10 +86,8 @@ namespace MeCab {
                             DCONF(REWRITE_FILE),
                             DCONF(POS_ID_FILE),
                             userdic.c_str());
-
       } else {
-
-        if (! opt_unknown && ! opt_matrix && ! opt_charcategory && ! opt_sysdic) {
+        if (!opt_unknown && !opt_matrix && !opt_charcategory && !opt_sysdic) {
           opt_unknown = opt_matrix = opt_charcategory = opt_sysdic = true;
         }
 
@@ -108,7 +100,7 @@ namespace MeCab {
         if (opt_unknown) {
           std::vector<std::string> tmp;
           tmp.push_back(DCONF(UNK_DEF_FILE));
-          param.setProfile("type", "2");
+          param.set("type", MECAB_UNK_DIC);
           Dictionary::compile(param, tmp,
                               DCONF(MATRIX_DEF_FILE),
                               DCONF(MATRIX_FILE),
@@ -121,7 +113,7 @@ namespace MeCab {
 
         if (opt_sysdic) {
           CHECK_DIE(dic.size()) << "no dictionaries are specified";
-          param.setProfile("type", "0");
+          param.set("type", MECAB_SYS_DIC);
           Dictionary::compile(param, dic,
                               DCONF(MATRIX_DEF_FILE),
                               DCONF(MATRIX_FILE),
@@ -148,7 +140,6 @@ namespace MeCab {
 #undef OCONF
 }
 
-int mecab_dict_index(int argc, char **argv)
-{
+int mecab_dict_index(int argc, char **argv) {
   return MeCab::DictionaryComplier::run(argc, argv);
 }
