@@ -1,26 +1,22 @@
-/*
-  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
-
-  $Id: viterbi.cpp,v 1.21 2006/07/09 11:26:27 taku-ku Exp $;
-
-  Copyright (C) 2001-2006 Taku Kudo <taku@chasen.org>
-  Copyright (C) 2004-2006 Nippon Telegraph and Telephone Corporation
-
-*/
-
+// MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+//
+//  $Id: viterbi.cpp 80 2007-02-06 01:52:25Z taku-ku $;
+//
+//  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
+//  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
 #include <cstring>
 #include <cmath>
 #include <algorithm>
 #include "param.h"
 #include "viterbi.h"
 #include "common.h"
+#include "string_buffer.h"
 #include "connector.h"
 
 namespace MeCab {
 
   namespace {
-    void calc_alpha(Node *n, double beta)
-    {
+    void calc_alpha(Node *n, double beta) {
       n->alpha = 0.0;
       for (Path *path = n->lpath; path; path = path->lnext)
         n->alpha = logsumexp(n->alpha,
@@ -28,8 +24,7 @@ namespace MeCab {
                              path == n->lpath);
     }
 
-    void calc_beta(Node *n, double beta)
-    {
+    void calc_beta(Node *n, double beta) {
       n->beta = 0.0;
       for (Path *path = n->rpath; path; path = path->rnext)
         n->beta = logsumexp(n->beta,
@@ -37,15 +32,16 @@ namespace MeCab {
                             path == n->rpath);
     }
 
-    bool partial_match(const char *f1, const char *f2)
-    {
-      char buf1[BUF_SIZE]; char *c1[64];
-      char buf2[BUF_SIZE]; char *c2[64];
+    bool partial_match(const char *f1, const char *f2) {
+      char buf1[BUF_SIZE];
+      char *c1[64];
+      char buf2[BUF_SIZE];
+      char *c2[64];
       std::strncpy(buf1, f1, sizeof(buf1));
       std::strncpy(buf2, f2, sizeof(buf2));
 
-      size_t n1 = MeCab::tokenizeCSV(buf1, c1, 64);
-      size_t n2 = MeCab::tokenizeCSV(buf2, c2, 64);
+      size_t n1 = MeCab::tokenizeCSV(buf1, c1, sizeof(c1));
+      size_t n2 = MeCab::tokenizeCSV(buf2, c2, sizeof(c2));
       size_t n  = _min(n1, n2);
 
       for (size_t i = 0; i < n; ++i) {
@@ -61,8 +57,7 @@ namespace MeCab {
 
   Viterbi::~Viterbi() { close(); }
 
-  bool Viterbi::open(Param &param, Tokenizer *t, Connector *c)
-  {
+  bool Viterbi::open(const Param &param, Tokenizer *t, Connector *c) {
     tokenizer_ = t;
     connector_ = c;
 
@@ -74,12 +69,12 @@ namespace MeCab {
     buildLattice_ = &Viterbi::buildBestLattice;
     analyze_ = &Viterbi::viterbi;
 
-    copy_sentence_ = param.getProfileInt("allocate-sentence");
+    copy_sentence_ = param.get<bool>("allocate-sentence");
 
-    partial_ = param.getProfileInt("partial");
+    partial_ = param.get<bool>("partial");
 
-    level_ = param.getProfileInt("lattice-level");
-    bool all_morphs = param.getProfileInt("all-morphs");
+    level_ = param.get<int>("lattice-level");
+    bool all_morphs = param.get<bool>("all-morphs");
 
     if (level_ >= 1) {
       path_freelist_.reset(new FreeList<Path>(PATH_FREELIST_SIZE));
@@ -91,9 +86,9 @@ namespace MeCab {
 
     if (all_morphs) {
       buildLattice_ = &Viterbi::buildAllLattice;
-      theta_    = param.getProfileFloat("theta");
-      int c = param.getProfileInt("cost-factor");
-      CHECK_FALSE(c != 0) << "cost-factor is empty";
+      theta_ = param.get<double>("theta");
+      int c = param.get<int>("cost-factor");
+      CHECK_FALSE(c > 0) << "cost-factor is empty";
       theta_ /= c;
     }
 
@@ -102,8 +97,7 @@ namespace MeCab {
 
   void Viterbi::close() {}
 
-  Node *Viterbi::analyze(const char *str, size_t len)
-  {
+  Node *Viterbi::analyze(const char *str, size_t len) {
     if (!partial_ && copy_sentence_) {
       sentence_.resize(len + 1);
       std::strncpy(&sentence_[0], str, len);
@@ -113,28 +107,28 @@ namespace MeCab {
     end_node_list_.resize(len + 4);
     begin_node_list_.resize(len + 4);
 
-    std::memset(&end_node_list_[0],   0, sizeof(Node *) * (len + 4));
-    std::memset(&begin_node_list_[0], 0, sizeof(Node *) * (len + 4));
+    std::memset(&end_node_list_[0],   0,
+                sizeof(end_node_list_[0]) * (len + 4));
+    std::memset(&begin_node_list_[0], 0,
+                sizeof(begin_node_list_[0]) *(len + 4));
 
     clear();
 
-    if (partial_ && !initConstraints(str, len)) return 0;
+    if (partial_ && !initConstraints(&str, &len)) return 0;
 
-    if (! (this->*analyze_)(str, len)) return 0;
+    if (!(this->*analyze_)(str, len)) return 0;
 
-    return (this->*buildLattice_)();
+    return(this->*buildLattice_)();
   }
 
-  void Viterbi::clear()
-  {
+  void Viterbi::clear() {
     tokenizer_->clear();
     Z_ = 0.0;
     if (path_freelist_.get()) path_freelist_->free();
   }
 
-  bool Viterbi::forwardbackward(const char *sentence, size_t len)
-  {
-    if (! this->viterbi(sentence, len)) return false;
+  bool Viterbi::forwardbackward(const char *sentence, size_t len) {
+    if (!this->viterbi(sentence, len)) return false;
 
     end_node_list_[0]->alpha = 0.0;
     for (int pos = 0;   pos <= static_cast<long>(len);  ++pos)
@@ -146,7 +140,7 @@ namespace MeCab {
       for (Node *node = end_node_list_[pos]; node; node = node->enext)
         calc_beta(node, theta_);
 
-    Z_ = begin_node_list_[len]->alpha; // alpha of EOS
+    Z_ = begin_node_list_[len]->alpha;  // alpha of EOS
 
     for (int pos = 0;   pos <= static_cast<long>(len);  ++pos)
       for (Node *node = begin_node_list_[pos]; node; node = node->bnext)
@@ -155,31 +149,32 @@ namespace MeCab {
     return true;
   }
 
-  bool Viterbi::viterbi(const char *sentence, size_t len)
-  {
+  bool Viterbi::viterbi(const char *sentence, size_t len) {
     bosNode_ = tokenizer_->getBOSNode();
+    bosNode_->begin_node_list = &begin_node_list_[0];
+    bosNode_->end_node_list = &end_node_list_[0];
+    bosNode_->sentence_length = len;
 
-    begin_ = const_cast<char *>(sentence);
+    begin_ = sentence;
     end_   = begin_ + len;
     bosNode_->surface = begin_;
     end_node_list_[0] = bosNode_;
 
-    for (size_t pos = 0; pos < len;  pos++){
+    for (size_t pos = 0; pos < len; ++pos) {
       if (end_node_list_[pos]) {
         Node * rNode = tokenizer_->lookup(begin_ + pos, end_);
         rNode = filterNode(rNode, pos);
         begin_node_list_[pos] = rNode;
-        if (! connect(pos, rNode)) return false;
+        if (!connect(pos, rNode)) return false;
       }
     }
 
-
     eosNode_ = tokenizer_->getEOSNode();
     eosNode_->surface = end_;
     begin_node_list_[len] = eosNode_;
-    for (size_t pos = len; static_cast<long>(pos) >= 0;  pos--) {
+    for (long pos = len; static_cast<long>(pos) >= 0; --pos) {
       if (end_node_list_[pos]) {
-        if (! connect(pos, eosNode_)) return 0;
+        if (!connect(pos, eosNode_)) return 0;
         break;
       }
     }
@@ -187,14 +182,13 @@ namespace MeCab {
     return true;
   }
 
-  Node *Viterbi::buildAllLattice()
-  {
-    if (! buildBestLattice()) return 0;
+  Node *Viterbi::buildAllLattice() {
+    if (!buildBestLattice()) return 0;
 
     Node *prev = bosNode_;
     size_t len = static_cast<size_t>(end_ - begin_);
 
-    for (int pos = 0;   pos <= static_cast<long>(len);  ++pos) {
+    for (long pos = 0; pos <= static_cast<long>(len); ++pos) {
       for (Node *node = begin_node_list_[pos]; node; node = node->bnext) {
         prev->next = node;
         node->prev = prev;
@@ -209,10 +203,9 @@ namespace MeCab {
     return bosNode_;
   }
 
-  Node *Viterbi::buildBestLattice()
-  {
+  Node *Viterbi::buildBestLattice() {
     Node *node = eosNode_;
-    for (Node *prevNode; node->prev; ){
+    for (Node *prevNode; node->prev;) {
       node->isbest = 1;
       prevNode = node->prev;
       prevNode->next = node;
@@ -222,12 +215,11 @@ namespace MeCab {
     return bosNode_;
   }
 
-  bool Viterbi::initConstraints(const char *&sentence,
-                                size_t &len)
-  {
-    constraint_buf_.resize(len + 1);
+  bool Viterbi::initConstraints(const char **sentence,
+                                size_t *len) {
+    constraint_buf_.resize(*len + 1);
     char *str = &constraint_buf_[0];
-    std::strncpy(str, sentence, len);
+    std::strncpy(str, *sentence, *len);
 
     std::vector<char *> lines;
     size_t lsize = tokenize(str, "\n", std::back_inserter(lines), 0xffff);
@@ -236,8 +228,8 @@ namespace MeCab {
     char* column[2];
     size_t pos = 1;
 
-    sentence_.resize(len + 1);
-    StringBuffer os(&sentence_[0], len + 1);
+    sentence_.resize(*len + 1);
+    StringBuffer os(&sentence_[0], *len + 1);
     os << ' ';
 
     for (size_t i = 0; i < lsize; ++i) {
@@ -261,26 +253,24 @@ namespace MeCab {
 
     os << '\0';
 
-    sentence = const_cast<const char*>(os.str());
-    len = pos - 1; // remove the last ' '
+    *sentence = const_cast<const char*>(os.str());
+    *len = pos - 1;  // remove the last ' '
 
     return true;
   }
 
-  Node* Viterbi::filterNode(Node *node, size_t pos)
-  {
-    if (! partial_) return node;
+  Node* Viterbi::filterNode(Node *node, size_t pos) {
+    if (!partial_) return node;
 
     Node *c = begin_node_list_[pos];
-    if (! c) return node;
+    if (!c) return node;
 
     Node *prev = 0;
     Node *result = 0;
 
     for (Node *n = node; n; n = n->bnext) {
-      if (c->length == n->length &&
-          (std::strcmp(c->feature, "*") == 0 ||
-           partial_match(c->feature, n->feature))) {
+      if (c->length == n->length && (std::strcmp(c->feature, "*") == 0 ||
+                                     partial_match(c->feature, n->feature))) {
         if (prev) {
           prev->bnext = n;
           prev = n;
@@ -291,7 +281,7 @@ namespace MeCab {
       }
     }
 
-    if (! result) result = c;
+    if (!result) result = c;
     if (prev) prev->bnext = 0;
 
     return result;
